function varargout = gasDemo(varargin)
% GASDEMO M-file for gasDemo.fig
%      GASDEMO, by itself, creates a new GASDEMO or raises the existing
%      singleton*.
%
%      H = GASDEMO returns the handle to a new GASDEMO or the handle to
%      the existing singleton*.
%
%      GASDEMO('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GASDEMO.M with the given input arguments.
%
%      GASDEMO('Property','Value',...) creates a new GASDEMO or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before gasDemo_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to gasDemo_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help gasDemo

% Last Modified by GUIDE v2.5 09-Feb-2007 09:42:05

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gasDemo_OpeningFcn, ...
                   'gui_OutputFcn',  @gasDemo_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before gasDemo is made visible.
function gasDemo_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gasDemo (see VARARGIN)

% Choose default command line output for gasDemo
handles.output = hObject;


% Load data file.
load gas.mat;

% Store contents of data file in handles stucture.
set(handles.gasChoice, 'String', Gas);
handles.M = M;

% Initialize molecular weight display (details in gasChoice callback).
choice = get(handles.gasChoice, 'Value');
M = handles.M(choice);
Mstr = sprintf('%6.2f', M);
set(handles.molWt, 'String', Mstr);

% Save modified handles structure.
guidata(hObject, handles);

% UIWAIT makes gasDemo wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = gasDemo_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on selection change in gasChoice.
function gasChoice_Callback(hObject, eventdata, handles)
% hObject    handle to gasChoice (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns gasChoice contents as cell array
%        contents{get(hObject,'Value')} returns selected item from gasChoice

% Get index of selected choice.
choice = get(hObject, 'Value');

% Use it to get molecular weight
M = handles.M(choice);

% Format and display the weight.
Mstr = sprintf('%6.2f', M);
set(handles.molWt, 'String', Mstr);

% --- Executes during object creation, after setting all properties.
function gasChoice_CreateFcn(hObject, eventdata, handles)
% hObject    handle to gasChoice (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


